==> fightorflight-fabric-0.9.0-sources.jar: me/rufia/fightorflight/client/renderer/PokemonPostRenderer.java <==
package me.rufia.fightorflight.client.renderer;

import com.cobblemon.mod.common.api.moves.Move;
import com.cobblemon.mod.common.entity.pokemon.PokemonEntity;
import me.rufia.fightorflight.CobblemonFightOrFlight;
import me.rufia.fightorflight.PokemonInterface;
import me.rufia.fightorflight.entity.PokemonAttackEffect;
import me.rufia.fightorflight.utils.PokemonUtils;
import net.minecraft.class_1309;
import net.minecraft.class_1921;
import net.minecraft.class_243;
import net.minecraft.class_2960;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_7833;
import org.joml.Matrix3f;
import org.joml.Matrix4f;

import java.awt.*;

//This class hasn't been used!
public class PokemonPostRenderer {
    private static final class_2960 BEAM_LOCATION = class_2960.method_60655(CobblemonFightOrFlight.MODID, "textures/entity/beam.png");
    private static final class_1921 BEAM_RENDER_TYPE;

    private static class_243 getPosition(class_1309 livingEntity, double yOffset, float partialTick) {
        double d = class_3532.method_16436((double) partialTick, livingEntity.field_6038, livingEntity.method_23317());
        double e = class_3532.method_16436((double) partialTick, livingEntity.field_5971, livingEntity.method_23318()) + yOffset;
        double f = class_3532.method_16436((double) partialTick, livingEntity.field_5989, livingEntity.method_23321());
        return new class_243(d, e, f);
    }

    public static void postRender(PokemonEntity entity, float entityYaw, float partialTicks, class_4587 poseStack, class_4597 buffer, int packedLight) {
        class_1309 livingEntity = entity.method_5968();
        int attackTime = ((PokemonInterface) (Object) entity).getAttackTime();
        boolean enabled = ((PokemonInterface) (Object) entity).usingBeam() && !entity.isBattling();
        if (livingEntity != null) {
            if (livingEntity.method_5805() && attackTime > 0 && enabled) {
                Move move = PokemonUtils.getMove(entity);
                if (move == null) {
                    CobblemonFightOrFlight.LOGGER.info("Trying to use a null move");
                    return;
                }
                //CobblemonFightOrFlight.LOGGER.info(move.getName());
                //float f = 0.2F;//entity.getAttackAnimationScale(partialTicks);
                float g = 40 + partialTicks + attackTime;//entity.getClientSideAttackTime() + partialTicks;
                Color color = Color.white;
                color = PokemonAttackEffect.getColorFromType(move.getType().getName());
                float h = g * 0.5F % 1.0F;
                float i = entity.method_5751();
                poseStack.method_22903();
                poseStack.method_46416(0.0F, i, 0.0F);
                class_243 vec3 = getPosition(livingEntity, (double) livingEntity.method_17682() * 0.5, partialTicks);
                class_243 vec32 = getPosition(entity, (double) i, partialTicks);
                class_243 vec33 = vec3.method_1020(vec32);
                float j = (float) (vec33.method_1033() + 1.0);
                vec33 = vec33.method_1029();
                float k = (float) Math.acos(vec33.field_1351);
                float l = (float) Math.atan2(vec33.field_1350, vec33.field_1352);
                poseStack.method_22907(class_7833.field_40716.rotationDegrees((1.5707964F - l) * 57.295776F));
                poseStack.method_22907(class_7833.field_40714.rotationDegrees(k * 57.295776F));
                boolean m = true;
                float n = g * 0.05F * -1.5F;
                int p = color.getRed();
                int q = color.getGreen();
                int r = color.getBlue();
                float s = 0.2F;
                float t = 0.282F;
                float u = class_3532.method_15362(n + 2.3561945F) * 0.282F;
                float v = class_3532.method_15374(n + 2.3561945F) * 0.282F;
                float w = class_3532.method_15362(n + 0.7853982F) * 0.282F;
                float x = class_3532.method_15374(n + 0.7853982F) * 0.282F;
                float y = class_3532.method_15362(n + 3.926991F) * 0.282F;
                float z = class_3532.method_15374(n + 3.926991F) * 0.282F;
                float aa = class_3532.method_15362(n + 5.4977875F) * 0.282F;
                float ab = class_3532.method_15374(n + 5.4977875F) * 0.282F;
                float ac = class_3532.method_15362(n + 3.1415927F) * 0.2F;
                float ad = class_3532.method_15374(n + 3.1415927F) * 0.2F;
                float ae = class_3532.method_15362(n + 0.0F) * 0.2F;
                float af = class_3532.method_15374(n + 0.0F) * 0.2F;
                float ag = class_3532.method_15362(n + 1.5707964F) * 0.2F;
                float ah = class_3532.method_15374(n + 1.5707964F) * 0.2F;
                float ai = class_3532.method_15362(n + 4.712389F) * 0.2F;
                float aj = class_3532.method_15374(n + 4.712389F) * 0.2F;
                float al = 0.0F;
                float am = 0.4999F;
                float an = -1.0F + h;
                float ao = j * 2.5F + an;
                class_4588 vertexConsumer = buffer.getBuffer(BEAM_RENDER_TYPE);
                class_4587.class_4665 pose = poseStack.method_23760();

                vertex(vertexConsumer, pose,  ac, j, ad, p, q, r, 0.4999F, ao);
                vertex(vertexConsumer, pose,  ac, 0.0F, ad, p, q, r, 0.4999F, an);
                vertex(vertexConsumer, pose,  ae, 0.0F, af, p, q, r, 0.0F, an);
                vertex(vertexConsumer, pose,  ae, j, af, p, q, r, 0.0F, ao);
                vertex(vertexConsumer, pose,  ag, j, ah, p, q, r, 0.4999F, ao);
                vertex(vertexConsumer, pose,  ag, 0.0F, ah, p, q, r, 0.4999F, an);
                vertex(vertexConsumer, pose,  ai, 0.0F, aj, p, q, r, 0.0F, an);
                vertex(vertexConsumer, pose,  ai, j, aj, p, q, r, 0.0F, ao);
                float ap = 0.0F;
                if (entity.field_6012 % 2 == 0) {
                    ap = 0.5F;
                }

                vertex(vertexConsumer, pose,  u, j, v, p, q, r, 0.5F, ap + 0.5F);
                vertex(vertexConsumer, pose,  w, j, x, p, q, r, 1.0F, ap + 0.5F);
                vertex(vertexConsumer, pose,  aa, j, ab, p, q, r, 1.0F, ap);
                vertex(vertexConsumer, pose,  y, j, z, p, q, r, 0.5F, ap);
                poseStack.method_22909();
            }
        }
    }

    private static void vertex(class_4588 consumer, class_4587.class_4665 pose, float x, float y, float z, int red, int green, int blue, float u, float v) {
        consumer.method_56824(pose, x, y, z).method_1336(red, green, blue, 255).method_22913(u, v).method_22922(class_4608.field_21444).method_60803(15728880).method_60831(pose, 0.0F, 1.0F, 0.0F);
    }

    static {
        BEAM_RENDER_TYPE = class_1921.method_23578(BEAM_LOCATION);
    }
}

==> fightorflight-fabric-0.10.0-sources.jar: me/rufia/fightorflight/client/renderer/PokemonPostRenderer.java <==
package me.rufia.fightorflight.client.renderer;

import com.cobblemon.mod.common.api.moves.Move;
import com.cobblemon.mod.common.entity.pokemon.PokemonEntity;
import me.rufia.fightorflight.CobblemonFightOrFlight;
import me.rufia.fightorflight.PokemonInterface;
import me.rufia.fightorflight.entity.PokemonAttackEffect;
import me.rufia.fightorflight.utils.PokemonUtils;
import net.minecraft.class_1309;
import net.minecraft.class_1921;
import net.minecraft.class_243;
import net.minecraft.class_2960;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_7833;
import java.awt.*;

//This class hasn't been used!
public class PokemonPostRenderer {
    private static final class_2960 BEAM_LOCATION = class_2960.method_60655(CobblemonFightOrFlight.MODID, "textures/entity/beam.png");
    private static final class_1921 BEAM_RENDER_TYPE;

    private static class_243 getPosition(class_1309 livingEntity, double yOffset, float partialTick) {
        double d = class_3532.method_16436((double) partialTick, livingEntity.field_6038, livingEntity.method_23317());
        double e = class_3532.method_16436((double) partialTick, livingEntity.field_5971, livingEntity.method_23318()) + yOffset;
        double f = class_3532.method_16436((double) partialTick, livingEntity.field_5989, livingEntity.method_23321());
        return new class_243(d, e, f);
    }

    public static void postRender(PokemonEntity entity, float entityYaw, float partialTicks, class_4587 poseStack, class_4597 buffer, int packedLight) {
        class_1309 livingEntity = entity.method_5968();
        int attackTime = ((PokemonInterface) entity).getAttackTime();
        boolean enabled = ((PokemonInterface) entity).usingBeam() && !entity.isBattling();
        if (livingEntity != null) {
            if (livingEntity.method_5805() && attackTime > 0 && enabled) {
                Move move = PokemonUtils.getMove(entity);
                if (move == null) {
                    CobblemonFightOrFlight.LOGGER.info("Trying to use a null move");
                    return;
                }
                float g = 40 + partialTicks + attackTime;//entity.getClientSideAttackTime() + partialTicks;
                Color color = PokemonAttackEffect.getColorFromType(move.getType().getName());
                float h = g * 0.5F % 1.0F;
                float i = entity.method_5751();
                poseStack.method_22903();
                poseStack.method_46416(0.0F, i, 0.0F);
                class_243 vec3 = getPosition(livingEntity, (double) livingEntity.method_17682() * 0.5, partialTicks);
                class_243 vec32 = getPosition(entity, i, partialTicks);
                class_243 vec33 = vec3.method_1020(vec32);
                float j = (float) (vec33.method_1033() + 1.0);
                vec33 = vec33.method_1029();
                float k = (float) Math.acos(vec33.field_1351);
                float l = (float) Math.atan2(vec33.field_1350, vec33.field_1352);
                poseStack.method_22907(class_7833.field_40716.rotationDegrees((1.5707964F - l) * 57.295776F));
                poseStack.method_22907(class_7833.field_40714.rotationDegrees(k * 57.295776F));
                boolean m = true;
                float n = g * 0.05F * -1.5F;
                int p = color.getRed();
                int q = color.getGreen();
                int r = color.getBlue();
                float s = 0.2F;
                float t = 0.282F;
                float u = class_3532.method_15362(n + 2.3561945F) * 0.282F;
                float v = class_3532.method_15374(n + 2.3561945F) * 0.282F;
                float w = class_3532.method_15362(n + 0.7853982F) * 0.282F;
                float x = class_3532.method_15374(n + 0.7853982F) * 0.282F;
                float y = class_3532.method_15362(n + 3.926991F) * 0.282F;
                float z = class_3532.method_15374(n + 3.926991F) * 0.282F;
                float aa = class_3532.method_15362(n + 5.4977875F) * 0.282F;
                float ab = class_3532.method_15374(n + 5.4977875F) * 0.282F;
                float ac = class_3532.method_15362(n + 3.1415927F) * 0.2F;
                float ad = class_3532.method_15374(n + 3.1415927F) * 0.2F;
                float ae = class_3532.method_15362(n + 0.0F) * 0.2F;
                float af = class_3532.method_15374(n + 0.0F) * 0.2F;
                float ag = class_3532.method_15362(n + 1.5707964F) * 0.2F;
                float ah = class_3532.method_15374(n + 1.5707964F) * 0.2F;
                float ai = class_3532.method_15362(n + 4.712389F) * 0.2F;
                float aj = class_3532.method_15374(n + 4.712389F) * 0.2F;
                float al = 0.0F;
                float am = 0.4999F;
                float an = -1.0F + h;
                float ao = j * 2.5F + an;
                class_4588 vertexConsumer = buffer.getBuffer(BEAM_RENDER_TYPE);
                class_4587.class_4665 pose = poseStack.method_23760();

                vertex(vertexConsumer, pose, ac, j, ad, p, q, r, 0.4999F, ao);
                vertex(vertexConsumer, pose, ac, 0.0F, ad, p, q, r, 0.4999F, an);
                vertex(vertexConsumer, pose, ae, 0.0F, af, p, q, r, 0.0F, an);
                vertex(vertexConsumer, pose, ae, j, af, p, q, r, 0.0F, ao);
                vertex(vertexConsumer, pose, ag, j, ah, p, q, r, 0.4999F, ao);
                vertex(vertexConsumer, pose, ag, 0.0F, ah, p, q, r, 0.4999F, an);
                vertex(vertexConsumer, pose, ai, 0.0F, aj, p, q, r, 0.0F, an);
                vertex(vertexConsumer, pose, ai, j, aj, p, q, r, 0.0F, ao);
                float ap = 0.0F;
                if (entity.field_6012 % 2 == 0) {
                    ap = 0.5F;
                }

                vertex(vertexConsumer, pose, u, j, v, p, q, r, 0.5F, ap + 0.5F);
                vertex(vertexConsumer, pose, w, j, x, p, q, r, 1.0F, ap + 0.5F);
                vertex(vertexConsumer, pose, aa, j, ab, p, q, r, 1.0F, ap);
                vertex(vertexConsumer, pose, y, j, z, p, q, r, 0.5F, ap);
                poseStack.method_22909();
            }
        }
    }

    private static void vertex(class_4588 consumer, class_4587.class_4665 pose, float x, float y, float z, int red, int green, int blue, float u, float v) {
        consumer.method_56824(pose, x, y, z).method_1336(red, green, blue, 255).method_22913(u, v).method_22922(class_4608.field_21444).method_60803(15728880).method_60831(pose, 0.0F, 1.0F, 0.0F);
    }

    static {
        BEAM_RENDER_TYPE = class_1921.method_23578(BEAM_LOCATION);
    }
}
